# Understanding Stepper Motor Specifications
---

## Bipolar Stepper Motor
---
- A bipolar stepper motor has an onboard driver that uses an H bridge circuit to reverse the current flow through the phases. By energising the phases while alternating the polarity, all the coils can be put to work turning the motor.

- In practical terms, this means that the coil windings are better utilised in a bipolar than a standard unipolar stepper motor (which only uses 50% of the wire coils at any one time), making bipolar stepper motors more powerful and efficient to run. 

- The trade-off is that they’re usually more expensive initially than standard unipolar versions, because unipolar stepper motors don’t require the current flow to be reversed in order to perform stepping functions - this makes their internal electronics much simpler and cheaper to produce.

> So, we must use the bipolar stepper motors.

## Rated Current
---
- This is the maximum current we may pass through both windings at the same time. The maximum current through one winding (which is what really matters when using microstepping) is rarely quoted and will be a little higher. However, even with one winding driven at the quoted rated current, the motor will get very hot. 

- The usual practice is to set the motor current to no more than about 85% of the rated current. Therefore, to get maximum torque out of the stepper motors without overheating them, we should choose motors with a current rating no more than 25% higher than the recommended maximum stepper driver current. 

> **MKS SBASE V1.3** uses the **DRV8825** stepper motor controller IC. The  provides 2.5 A maximum drive current at 24 V. Considering half of the maximum drive current (1.25 A) at 12 V, to get maximum torque out of the motors without overheating them, we should choose motors with a current rating around 1.56 A (25% higher than 1.25 A).

## Holding torque
---
- This is the maximum torque that the motor can provide with both windings energised at full current before it starts jumping steps.The holding torque with one winding energised at the rated current is about ***1/sqrt(2)*** times that. 

- The torque is proportional to current (except at very low currents), so for example if we set the drivers to 85% of the motor rated current, then the maximum torque will be ***85% * 0.707 = 60%*** of the specified holding torque.

- ***Rated current comparison***: 85% of 0.4 A rated current = 0.34 A, 85% of 1.8 A rated current = 1.53 A. 
- ***Holding torque comparison***: 60% of 40 Ncm = 24 Ncm, 60% of 50 Ncm = 30 Ncm.

> So, choosing the motor having 1.8 A rated current and setting the drivers at 1.53 A, we can get maximum torque of 30 Ncm (60%) out of the motors without overheating them.

## Step angle
---
- There are two common step angles: 0.9 and 1.8 degrees per full step, corresponding to 400 and 200 steps/revolution. 

- 0.9 deg motors have slightly lower holding torque than similar 1.8 deg motors from the same manufacturer. 

> Most 3D printers use 1.8 deg/step motors.

## Resistance and rated voltage
---
- These are simply the resistance per phase, and the voltage drop across each phase when the motor is stationary and the phase is passing its rated current (which is the product of the resistance and the rated current).

- These are unimportant, except that the rated voltage should be well below the power supply voltage to the stepper driver.

> The 0.4 A stepper motor has the rated phase voltage of 12 V (phase resistance_30 ohms * rated current per phase_0.4 A). Providing 12 V supply voltage to the **DRV8825** stepper motor controller IC, we must use the 1.8 A rated current stepper motor. Because it has the rated phase voltage of 2.7 V (phase resistance_1.5 ohms * rated current per phase_1.8 A), which is much lower than the supply voltage (12 V) compared to the 0.4 A stepper motor.

## Inductance
---

- The inductance of the motor affects how fast the stepper motor driver can drive the motor before the torque drops off. If we temporarily ignore the back emf due to rotation and the rated motor voltage is much less than the driver supply voltage, then the maximum revs/second before torque drops off is:

> ***revs_per_second = (2 * supply_voltage)/(steps_per_rev * pi * inductance * current)***

- If the motor is driving a GT2 belt via a pulley, this gives the maximum speed in mm/sec as:

> ***speed = (4 * pulley_teeth * supply_voltage)/(steps_per_rev * pi * inductance * current)***

- **Example**: a 1.8 deg/step (i.e. 200 steps/rev) motor with 3.2 mH inductance run at 1.5 A using a 12 V supply, and driving a GT2 belt with 20 tooth pulley would start losing torque at about 318 mm/sec. This is the belt speed, which on a CoreXY or delta printer is not the same as the head speed.

- In practice the torque will drop off sooner than this because of the back emf caused by motion, and because the above doesn't allow for the winding resistance. Low inductance motors also have low back emf due to rotation.

> What this means is that if we want to achieve high speeds, we need low inductance motors and high supply voltage. So, we must choose the 1.8 A stepper motor having lower inductance (3.2 mH) compared to the 0.4 A stepper motor (58 mH).

## General Recommendations
---
- Choose motors with rated current of at least 1.2 A.

- Plan to run each stepper motor at between 50% and 85% of its rated current.

- Nema 17 is the most popular size used in 3D printers. Nema 14 is an alternative in a highly-geared extruder. Use Nema 23 motors if you cannot get sufficient torque from long Nema 17 motors. 

- Avoid motors with rated voltage (or product of rated current and phase resistance) > 4 V or inductance > 4 mH.

- Choose 0.9 deg/step motors where you want extra positioning accuracy, e.g. for the tower motors of a delta printer. Otherwise choose 1.8 deg/step motors.

- If you use any 0.9 deg/step motors, or high torque motors, use 24V power so that you will be able to maintain torque at higher speeds.




